PyBaccarat: pybaccarat.baccaratsystems Namespace Reference

PyBaccarat visit the ministry of silly walks

Classes
pybaccarat.baccaratsystems Namespace Reference

This module is collection of classes used with systems for playing the game Baccarat. More...

## Classes
class | BaccSys
class | Dragon
| TBD. More...
class | EZDragon
| Card count system for EZ-Baccarat Dragon side bet. More...
class | interactive
| Play Baccarat with interactive selection of hand plays. More...
class | ValSys

## Detailed Description

This module is collection of classes used with systems for playing the game Baccarat.

Author
  fulkg.nosp@m.l@gm.nosp@m.ail.c.nosp@m.om

Version
  0.01

Author
  fulkg.nosp@m.l@gm.nosp@m.ail.c.nosp@m.om

Version
  0.13